@@ -329,17 +329,14 @@ void ControlWidget::sendREG()
 
 void ControlWidget::sendCBM()
 {
-    QString pdu = p->constructCBMessage(ui->leMessageCode->text(),ui->cbGeographicalScope->currentIndex(),
-                       ui->leUpdateNumber->text(),ui->leChannel->text(),ui->leScheme->text(),
-                       ui->cbLanguage->currentIndex(),ui->leNumPages->text(),ui->lePage->text(),
-                       ui->teContent->toPlainText());
-
-    emit unsolicitedCommand(QString("+CBM: ")+QString::number(pdu.length()/2)+'\r'+'\n'+ pdu);
+    p->constructCBMessage(ui->leMessageCode->text(),ui->cbGeographicalScope->currentIndex(),
+                       ui->leUpdateNumber->text(),ui->leChannel->text(),
+                       ui->cbLanguage->currentIndex(),ui->teContent->toPlainText());
 }
 
 void ControlWidget::sendSMSMessage()
 {
-    if (ui->leSMSClass->text().isEmpty()) {
+    if (ui->leMessageSender->text().isEmpty()) {
         p->warning(tr("Invalid Sender"),
                 tr("Sender must not be empty"));
         return;
@@ -714,7 +711,7 @@ QString Script::Run(const QString &name, const QDBusMessage &msg)
     QScriptValue qsScript = engine.evaluate(contents);
     if (qsScript.isError()) {
         QString info = fileName + ", line " + qsScript.property("lineNumber").toString() + ", " + qsScript.toString();
-        QDBusMessage reply = msg.createErrorReply(SERVICE "Error.ScriptExecError", info);
+        QDBusMessage reply = msg.createErrorReply(SERVICE ".Error.ScriptExecError", info);
         QDBusConnection::sessionBus().send(reply);
         return QString();
     }
